from comring.lib import odoo
from comring.lib import config
import getpass
import logging
import csv


def cancel_picking(odoo_client, ids):
    res = odoo_client.call('stock.picking', 'action_cancel', [ids], {})
    logging.info('Cancel status: %s', res)

def send_back_picking(odoo_client, ids):
    logging.info("You know what? Just do it yourself OK, it's easier")

def check_status(odoo_client, ref_list):
    records = odoo_client.search_read('stock.picking', [('name', 'in', ref_list)], ['id', 'name', 'state'])
    if not records:
        logging.error('Cannot get data form Odoo')
        return False
    cancel_list = []
    send_back_list = []
    for rec in records:
        action = 'None'
        if rec['state'] in ['partially_available', 'assigned']:
            action = 'cancel'
            cancel_list.append(rec['id'])
        else:
            if rec['state'] == 'done':
                action = 'send back'
                send_back_list.append(rec['id'])
        print('%f: %f', rec['name'], action)
    
    if cancel_list:
        cancel_picking(odoo_client, cancel_list)
    if send_back_list:
        send_back_picking(odoo_client, send_back_list)

    return True


def get_ref_list():
    data = """NDC/OUT/2018AUG04-BANDUNG-WARDAH-NOR-10
NDC/OUT/2018AUG04-BANDUNG-WARDAH-NOR-11
NDC/OUT/2018AUG04-BANDUNG-WARDAH-NOR-12
NDC/OUT/2018AUG04-BANDUNG-WARDAH-NOR-13
NDC/OUT/2018AUG04-BANDUNG-WARDAH-NOR-2
NDC/OUT/2018AUG04-BANDUNG-WARDAH-NOR-3
NDC/OUT/2018AUG04-BANDUNG-WARDAH-NOR-4
NDC/OUT/2018AUG04-BANDUNG-WARDAH-NOR-5
NDC/OUT/2018AUG04-BEKASI-WARDAH-NOR-10
NDC/OUT/2018AUG04-BEKASI-WARDAH-NOR-11
NDC/OUT/2018AUG04-BEKASI-WARDAH-NOR-12
NDC/OUT/2018AUG04-BEKASI-WARDAH-NOR-13
NDC/OUT/2018AUG04-BEKASI-WARDAH-NOR-2
NDC/OUT/2018AUG04-BEKASI-WARDAH-NOR-3
NDC/OUT/2018AUG04-BEKASI-WARDAH-NOR-4
NDC/OUT/2018AUG04-BEKASI-WARDAH-NOR-5
NDC/OUT/2018AUG04-BOGOR-WARDAH-NOR-10
NDC/OUT/2018AUG04-BOGOR-WARDAH-NOR-11
NDC/OUT/2018AUG04-BOGOR-WARDAH-NOR-12
NDC/OUT/2018AUG04-BOGOR-WARDAH-NOR-13
NDC/OUT/2018AUG04-BOGOR-WARDAH-NOR-2
NDC/OUT/2018AUG04-BOGOR-WARDAH-NOR-3
NDC/OUT/2018AUG04-BOGOR-WARDAH-NOR-4
NDC/OUT/2018AUG04-BOGOR-WARDAH-NOR-5
NDC/OUT/2018AUG04-CIREBON-WARDAH-NOR-10
NDC/OUT/2018AUG04-CIREBON-WARDAH-NOR-11
NDC/OUT/2018AUG04-CIREBON-WARDAH-NOR-12
NDC/OUT/2018AUG04-CIREBON-WARDAH-NOR-13
NDC/OUT/2018AUG04-CIREBON-WARDAH-NOR-2
NDC/OUT/2018AUG04-CIREBON-WARDAH-NOR-3
NDC/OUT/2018AUG04-CIREBON-WARDAH-NOR-4
NDC/OUT/2018AUG04-CIREBON-WARDAH-NOR-5
NDC/OUT/2018AUG04-JAKARTA-WARDAH-NOR-10
NDC/OUT/2018AUG04-JAKARTA-WARDAH-NOR-11
NDC/OUT/2018AUG04-JAKARTA-WARDAH-NOR-12
NDC/OUT/2018AUG04-JAKARTA-WARDAH-NOR-13
NDC/OUT/2018AUG04-JAKARTA-WARDAH-NOR-2
NDC/OUT/2018AUG04-JAKARTA-WARDAH-NOR-3
NDC/OUT/2018AUG04-JAKARTA-WARDAH-NOR-4
NDC/OUT/2018AUG04-JAKARTA-WARDAH-NOR-5
NDC/OUT/2018AUG04-KEDIRI-WARDAH-NOR-10
NDC/OUT/2018AUG04-KEDIRI-WARDAH-NOR-11
NDC/OUT/2018AUG04-KEDIRI-WARDAH-NOR-12
NDC/OUT/2018AUG04-KEDIRI-WARDAH-NOR-13
NDC/OUT/2018AUG04-KEDIRI-WARDAH-NOR-2
NDC/OUT/2018AUG04-KEDIRI-WARDAH-NOR-3
NDC/OUT/2018AUG04-KEDIRI-WARDAH-NOR-4
NDC/OUT/2018AUG04-KEDIRI-WARDAH-NOR-5
NDC/OUT/2018AUG04-LAMPUNG-WARDAH-NOR-10
NDC/OUT/2018AUG04-LAMPUNG-WARDAH-NOR-11
NDC/OUT/2018AUG04-LAMPUNG-WARDAH-NOR-12
NDC/OUT/2018AUG04-LAMPUNG-WARDAH-NOR-13
NDC/OUT/2018AUG04-LAMPUNG-WARDAH-NOR-2
NDC/OUT/2018AUG04-LAMPUNG-WARDAH-NOR-3
NDC/OUT/2018AUG04-LAMPUNG-WARDAH-NOR-4
NDC/OUT/2018AUG04-LAMPUNG-WARDAH-NOR-5
NDC/OUT/2018AUG04-MALANG-WARDAH-NOR-10
NDC/OUT/2018AUG04-MALANG-WARDAH-NOR-11
NDC/OUT/2018AUG04-MALANG-WARDAH-NOR-12
NDC/OUT/2018AUG04-MALANG-WARDAH-NOR-13
NDC/OUT/2018AUG04-MALANG-WARDAH-NOR-2
NDC/OUT/2018AUG04-MALANG-WARDAH-NOR-3
NDC/OUT/2018AUG04-MALANG-WARDAH-NOR-4
NDC/OUT/2018AUG04-MALANG-WARDAH-NOR-5
NDC/OUT/2018AUG04-PALEMBANG-WARDAH-NOR-10
NDC/OUT/2018AUG04-PALEMBANG-WARDAH-NOR-11
NDC/OUT/2018AUG04-PALEMBANG-WARDAH-NOR-12
NDC/OUT/2018AUG04-PALEMBANG-WARDAH-NOR-13
NDC/OUT/2018AUG04-PALEMBANG-WARDAH-NOR-2
NDC/OUT/2018AUG04-PALEMBANG-WARDAH-NOR-3
NDC/OUT/2018AUG04-PALEMBANG-WARDAH-NOR-4
NDC/OUT/2018AUG04-PALEMBANG-WARDAH-NOR-5
NDC/OUT/2018AUG04-PURWOKERTO-WARDAH-NOR-10
NDC/OUT/2018AUG04-PURWOKERTO-WARDAH-NOR-11
NDC/OUT/2018AUG04-PURWOKERTO-WARDAH-NOR-12
NDC/OUT/2018AUG04-PURWOKERTO-WARDAH-NOR-13
NDC/OUT/2018AUG04-PURWOKERTO-WARDAH-NOR-2
NDC/OUT/2018AUG04-PURWOKERTO-WARDAH-NOR-3
NDC/OUT/2018AUG04-PURWOKERTO-WARDAH-NOR-4
NDC/OUT/2018AUG04-PURWOKERTO-WARDAH-NOR-5
NDC/OUT/2018AUG04-SEMARANG-WARDAH-NOR-10
NDC/OUT/2018AUG04-SEMARANG-WARDAH-NOR-11
NDC/OUT/2018AUG04-SEMARANG-WARDAH-NOR-12
NDC/OUT/2018AUG04-SEMARANG-WARDAH-NOR-13
NDC/OUT/2018AUG04-SEMARANG-WARDAH-NOR-2
NDC/OUT/2018AUG04-SEMARANG-WARDAH-NOR-3
NDC/OUT/2018AUG04-SEMARANG-WARDAH-NOR-4
NDC/OUT/2018AUG04-SEMARANG-WARDAH-NOR-5
NDC/OUT/2018AUG04-SERANG-WARDAH-NOR-10
NDC/OUT/2018AUG04-SERANG-WARDAH-NOR-11
NDC/OUT/2018AUG04-SERANG-WARDAH-NOR-12
NDC/OUT/2018AUG04-SERANG-WARDAH-NOR-13
NDC/OUT/2018AUG04-SERANG-WARDAH-NOR-2
NDC/OUT/2018AUG04-SERANG-WARDAH-NOR-3
NDC/OUT/2018AUG04-SERANG-WARDAH-NOR-4
NDC/OUT/2018AUG04-SERANG-WARDAH-NOR-5
NDC/OUT/2018AUG04-SOLO-WARDAH-NOR-10
NDC/OUT/2018AUG04-SOLO-WARDAH-NOR-11
NDC/OUT/2018AUG04-SOLO-WARDAH-NOR-12
NDC/OUT/2018AUG04-SOLO-WARDAH-NOR-13
NDC/OUT/2018AUG04-SOLO-WARDAH-NOR-2
NDC/OUT/2018AUG04-SOLO-WARDAH-NOR-3
NDC/OUT/2018AUG04-SOLO-WARDAH-NOR-4
NDC/OUT/2018AUG04-SOLO-WARDAH-NOR-5
NDC/OUT/2018AUG04-SURABAYA-WARDAH-NOR-10
NDC/OUT/2018AUG04-SURABAYA-WARDAH-NOR-11
NDC/OUT/2018AUG04-SURABAYA-WARDAH-NOR-12
NDC/OUT/2018AUG04-SURABAYA-WARDAH-NOR-13
NDC/OUT/2018AUG04-SURABAYA-WARDAH-NOR-2
NDC/OUT/2018AUG04-SURABAYA-WARDAH-NOR-3
NDC/OUT/2018AUG04-SURABAYA-WARDAH-NOR-4
NDC/OUT/2018AUG04-SURABAYA-WARDAH-NOR-5
NDC/OUT/2018AUG04-TASIK-WARDAH-NOR-10
NDC/OUT/2018AUG04-TASIK-WARDAH-NOR-11
NDC/OUT/2018AUG04-TASIK-WARDAH-NOR-12
NDC/OUT/2018AUG04-TASIK-WARDAH-NOR-13
NDC/OUT/2018AUG04-TASIK-WARDAH-NOR-2
NDC/OUT/2018AUG04-TASIK-WARDAH-NOR-3
NDC/OUT/2018AUG04-TASIK-WARDAH-NOR-4
NDC/OUT/2018AUG04-TASIK-WARDAH-NOR-5
NDC/OUT/2018AUG04-TEGAL-WARDAH-NOR-10
NDC/OUT/2018AUG04-TEGAL-WARDAH-NOR-11
NDC/OUT/2018AUG04-TEGAL-WARDAH-NOR-12
NDC/OUT/2018AUG04-TEGAL-WARDAH-NOR-13
NDC/OUT/2018AUG04-TEGAL-WARDAH-NOR-2
NDC/OUT/2018AUG04-TEGAL-WARDAH-NOR-3
NDC/OUT/2018AUG04-TEGAL-WARDAH-NOR-4
NDC/OUT/2018AUG04-TEGAL-WARDAH-NOR-5
NDC/OUT/2018AUG04-YOGYAKARTA-WARDAH-NOR-10
NDC/OUT/2018AUG04-YOGYAKARTA-WARDAH-NOR-11
NDC/OUT/2018AUG04-YOGYAKARTA-WARDAH-NOR-12
NDC/OUT/2018AUG04-YOGYAKARTA-WARDAH-NOR-13
NDC/OUT/2018AUG04-YOGYAKARTA-WARDAH-NOR-2
NDC/OUT/2018AUG04-YOGYAKARTA-WARDAH-NOR-3
NDC/OUT/2018AUG04-YOGYAKARTA-WARDAH-NOR-4
NDC/OUT/2018AUG04-YOGYAKARTA-WARDAH-NOR-5"""
    return data.splitlines()


if __name__ == '__main__':
    env = 'live'

    logging.basicConfig(level=logging.DEBUG, format='%(asctime)s %(levelname)s: %(message)s')

    conf = config.Config()

    url = conf.env_get(env, 'server_url')
    db = conf.env_get(env, 'database')
    user = conf.env_get(env, 'user')

    logging.info('Logging in to %s database [%s] as [%s]', url, db, user)
    passwd = ''
    try:
        passwd = getpass.getpass(prompt='Password for {}: '.format(user))
    except Exception as err:
        logging.error('ERROR while getting password', exc_info=err)
        exit(1)

    osv = odoo.Odoo(url)
    client = None
    try:
        client = osv.login(db, user, passwd)
        assert client
    except Exception as err:
        logging.error('ERROR while logging in', exc_info=err)
        exit(2)

    check_status(client, get_ref_list())
    logging.info('Done')



